<div class="profile-page-wrapper">

	<?php wpj_display_user_cover_image(); ?>

	<!-- Content -->
	<div class="profile-split-content ui stackable grid">

		<!-- Left Sidebar -->
		<div class="profile-sidebar five wide column">
			<div class="ui segment user-info-wrapper">

				<?php wpj_display_user_avatar();

				wpj_display_user_status_icon(); ?>

				<!-- User main info -->
				<div class="user-info">

					<h2 class="user-title-wrapper">

						<?php echo apply_filters( 'wpj_user_profile_username_filter', wpj_get_user_display_type( $uid ), wpj_get_URL_user( 'userdata' ) );

						wpj_display_company_name();

						wpj_display_user_info_icons( $uid, array( 'status' => 'no', 'country' => 'no' ) ); ?>

					</h2>

					<?php wpj_display_user_tagline();

					wpj_display_user_rating_info( $uid ); ?>

				</div><!-- END "user-info" -->

				<!-- User details info( white sidebar ) -->
				<?php $WPJUserProfile->getFieldsContent( 'white_sidebar' ); ?>

				<?php do_action( 'wpj_after_user_profile_info_content', $uid, wpj_get_URL_user( 'username' ) ); ?>

			</div><!-- END "user-info-wrapper" -->

			<!-- User more details info( transparent sidebar ) -->
			<?php $WPJUserProfile->getFieldsContent( 'transparent_sidebar' ); ?>

		</div><!-- END Left Sidebar "profile-sidebar" -->

		<!-- Right Content( main content ) -->
		<div class="eleven wide column">

			<?php if ( wpj_user_profile_has_icons() ) { ?>

				<div class="profile-main-content user-icons-wrapper">

					<div class="ui <?php echo wpj_number_to_string( $item_per_row ); ?> doubling cards">

						<?php $WPJUserProfile->getFieldsContent( 'icons' ); ?>

					</div>

				</div>

				<div class="ui hidden divider"></div>

			<?php }

			$WPJUserProfile->getFieldsContent( 'main_content' ); ?>

		</div>

	</div><!-- END Content "profile-split-content" -->

</div><!-- END "profile-page-wrapper" -->
